@@ -20,7 +20,7 @@ parser.add_argument("--env", help="Sets environment. Development, Production, QA
 parser.add_argument("--code", help="Sets Storis client code", type=str)
 parser.add_argument("--events", help="Sets Storis client code")
 
-args = parser.parse_args()
+args, unknown = parser.parse_known_args()
 
 #Set environment
 Environment.set_environment(args.env)
